==> 2.17-pre1.tar.gz: essentials/.github/ISSUE_TEMPLATE/request-a-feature.md <==
---
name: Request a feature
about: Suggest a feature you want to see in EssentialsX!

---

<!-- EssentialsX feature request guide

Fill out the template. Don't write inside the arrows as they will be hidden
when you post your issue.

Not sure if your feature fits in EssentialsX? Feel free to ask on our Discord
server: https://discord.gg/F7gexAQ

If you have a feature suggestion for EssentialsX, read the following tips:

1.  Fill out the template.
      This will help us understand what you're requesting and why you want us
      to add it.

2.  Keep it simple.
      Make sure it's easy to understand what you're requesting. A good way is
      to keep it to one request per GitHub issue, as we can then easily track
      feature requests.

3.  Check whether it has already been asked or added.
      You can search the issue tracker to see if your feature has already been
      requested at https://github.com/EssentialsX/Essentials/issues. You can
      also check the wiki at https://essentialsx.github.io/ to see if the
      feature was recently added.

4.  Ask yourself: "Does this belong in EssentialsX?"
      There are lots of features that we reject because most servers won't
      need or use them. If your feature is very specific or already exists in
      another plugin, it might not be a good fit for EssentialsX.

5.  Delete this line and all above lines before posting your issue!       -->

### Feature request

**Feature description**
<!-- What feature are you suggesting? -->

**How the feature is useful**
<!-- How is the feature useful to players, server owners and/or developers? -->

==> 2.18.2.tar.gz: essentials/.github/ISSUE_TEMPLATE/request-a-feature.md <==
---
name: Request a feature
about: Suggest a feature you want to see in EssentialsX!
labels: 'type: enhancement'

---

<!-- EssentialsX feature request guide

NOTE: Failure to fill out this template properly may result in your issue being
      delayed or ignored.

Don't type between any arrows in the template, as this text will be hidden.
This includes this header block and any other explanatory text blocks.

Not sure if your feature fits in EssentialsX? Feel free to ask on our Discord
server: https://discord.gg/F7gexAQ

If you have a feature suggestion for EssentialsX, read the following tips:

1.  Fill out the template.
      This will help us understand what you're requesting and why you want us
      to add it.

2.  Keep it simple.
      Make sure it's easy to understand what you're requesting. A good way is
      to keep it to one request per GitHub issue, as we can then easily track
      feature requests.

3.  Check whether it has already been asked or added.
      You can search the issue tracker to see if your feature has already been
      requested at https://github.com/EssentialsX/Essentials/issues. You can
      also check the changelogs to see if the feature was recently added:
      https://github.com/EssentialsX/Essentials/releases

4.  Ask yourself: "Does this belong in EssentialsX?"
      There are lots of features that we reject because most servers won't
      need or use them. If your feature is very specific or already exists in
      another plugin, it might not be a good fit for EssentialsX.

-->

### Feature request

**Feature description:**  
<!-- What feature are you suggesting? Type below this line. -->

**How the feature is useful:**  
<!--
    How is the feature useful to players, server owners and/or developers?
    Type below this block.
-->
